@@ -7,9 +7,7 @@
 import os
 import datetime
 import logging
-import statistics
 from functools import partial
-import multiprocessing
 import concurrent.futures
 
 import tqdm
@@ -21,8 +19,7 @@ from jcast.sequences import Sequence
 from jcast import __version__
 
 
-
-def jcast(args):
+def runjcast(args):
     """
     main look for jcast flow.
 
@@ -81,7 +78,7 @@ def jcast(args):
 
     # number of threads for concurrency
     # cap it at cpu count -1 for now
-    threads = min(args.num_threads, multiprocessing.cpu_count()-1)
+    threads = min(args.num_threads, os.cpu_count()-1)
 
     #
     # Main loop through every line of each of the five rMATS files to make junction object, then translate them
@@ -102,6 +99,9 @@ def jcast(args):
                                         directory_to_write=directory_to_write,
                                         )
 
+        #
+        # Concurrent futures
+        #
         with concurrent.futures.ThreadPoolExecutor(max_workers=threads) as pool:
             for i, f in enumerate(tqdm.tqdm(pool.map(
                     translate_one_partial,
@@ -110,10 +110,25 @@ def jcast(args):
                     total=len(junctions),
                     desc='Processing {0} Junctions'.format(rma.jxn_type[0]),
             )):
-                main_log.info('>>>>>> Now doing junction {0} for gene {1}'.format(junctions[i].name,
-                                                                                  junctions[i].gene_symbol))
+                main_log.info('>>>>>> Now doing {0} junction {1} for gene {2}'.format(junctions[i].junction_type,
+                                                                                      junctions[i].name,
+                                                                                      junctions[i].gene_symbol,
+                                                                                  ))
                 main_log.info(f)
 
+        #
+        # Single threaded for-loop
+        #
+        # for jx in tqdm.tqdm(junctions,
+        #                     total=len(junctions),
+        #                     desc='Processing {0} Junctions'.format(rma.jxn_type[0]),
+        #                     ):
+        #     translate_one_partial(jx)
+        #     main_log.info('>>>>>> Now doing {0} junction {1} for gene {2}'.format(jx.junction_type,
+        #                                                                           jx.name,
+        #                                                                           jx.gene_symbol,
+        #                                                                           ))
+
     return True
 
 
@@ -182,8 +197,7 @@ def _translate_one(junction,
     sequence.make_slice_localgenome(genome.genome)
 
     #
-    # The next section is the six-frame translational by-pass. If the --sixframe flag is on,
-    # Then do six-frame with all the qualifying junctions instead
+    # if the --sixframe flag is there, do six-frame translation with all qualifying junctions as well
     #
 
     if args.sixframe:
@@ -202,7 +216,7 @@ def _translate_one(junction,
 
 
     #
-    # Translate into peptides
+    # translate to peptides
     #
     sequence.translate(use_phase=True)
 
@@ -282,7 +296,7 @@ def _translate_one(junction,
                                       suffix='T4',
                                       merge_length=10)
 
-            callback_ = 'PARTIAL 4.  Slice 2 hit a stop codon. Used longest phase.\n\n'
+            callback_ = 'PARTIAL 4. Slice 2 hit a stop codon. Used longest phase.\n\n'
             return callback_
 
     # Force-translate slice 1 if slice 1 hits PTC:
@@ -354,21 +368,19 @@ def main():
                         default=0.01,
                         type=float)
 
-
     parser.add_argument('-s', '--sixframe', action='store_true',
                         help='also do six-frame translation instead with the junctions [default: False]',
                         )
 
-    parser.set_defaults(func=jcast)
-
-    # Print help message if no arguments are given
+    parser.set_defaults(func=runjcast)
 
+    # print help message if no arguments are given
     if len(sys.argv[1:]) == 0:
         parser.print_help()
         parser.exit()
 
-    # Parse all the arguments
+    # parse all the arguments
     args = parser.parse_args()
 
-    # Run the function in the argument
+    # run the function in the argument
     args.func(args)
